# Paiement Sogenactif

#### Scénario

Documentation sur l'intégration via notre service Web pour dialoguer avec Sogenactif :

`https://sogenactif.documentation.sogenactif.com/fr/guide-de-demarrage-rapide.html`

Le parcours client est le suivant :

1. Validation du panier de votre page commerçant,
2. Redirection du client sur la page Sogenactif de sélection du moyen de paiement,
3. Saisie des données carte,
4. Authentification du client sur une page de sa banque (si 3-D Secure),
5. Affichage du ticket de caisse par Sogenactif ,
6. Confirmation de la prise en compte de la commande sur votre page commerçant.

Dans cette cinématique que la saisie des données de la carte s'effectue chez Sogenactif .Vous n’avez pas connaissance de ces données sensibles.

#### Détail sur les champs traités a envoyer

1. Les différentes fonctions possibles font l’objet de requêtes spécifiques.

2. Une requête est composée de champs génériques et de champs de type container (tableaux).

3. Un container est une structure utilisée afin de regrouper fonctionnellement les données.

4. Si le champ est de type container, cette précision est indiquée dans la colonne commentaire qui renvoie à la partie 
dédiée détaillant le contenu de tous les champs de ce type.

Version HTML

3 infos obligatoires (dont une optionnel mais pas utilisé dans notre cas):


| Donnée du formulaire   | Présence  | Description     |
| :--------------------: | :-------: | :-------------: |
| Data | 	Obligatoire |	Ensemble des champs de la requête de paiement (champs décrits ci-dessous dans la partie « construire la requête de paiement : donnée Data ») |
| InterfaceVersion | 	Obligatoire |	L’interface version définit la version de la requête et de la réponse échangée avec le serveur de paiement. Les champs décrits ci-après correspondent à l' interfaceVersion HP_ 2.30 . Si vous utilisez une version antérieure du connecteur, il est possible que certains champs ne soient pas disponibles et ne puissent être utilisés. |
| Seal | 	Obligatoire |	Signature de la donnée Data qui permet de garantir la sécurité de la requête de paiement |
| Encode | 	Optionnel |	Dans le cas où la donnée Data comporte des caractères spéciaux, vous devez changer l’encodage. La valeur du champ Encode précise la méthode d’encodage utilisée pour la donnée Data. En cas d’encodage, le seal est calculé sur la donnée data encodé. |

Valeurs:

    Base64 : encodage du champ data en base 64
    Base64URL : encodage du champ data en base64URL

Version JSON

Il faut bien distinguer de la partie `data` qui est l'ensemble des champs **sauf** : 
* keyVersion
* seal

**C'est important de comprendre que le seal lors de son encodage de prend pas les infos de `keyVersion` et bien évidemment de `seal`
car c'est le seal lui-me eet il sera encodé par la suite.**

#### Seal

C'est l'encodage en utf8 des données (**en JSON il faut deguager la `keyVersion`**, en `POST` on a une clé `DATA` isolé)
qui est ensuite encodé en HMAC_256

**Exemple d'encodage en php**

```php
<?php

// …

// Seal computation thanks to hash sorted data hash with merchant key

$secretKey = 'XXX'; 
$data_to_send= utf8_encode($data);

$seal=hash_hmac('sha256', $data_to_send, $secretKey);

// …
// …

?>
```

### Url de test

Les url de test ressemble trait pour trait à celles de la solution de BNP Paris Bas, qui eux, ont une doc d'API assez clair: 

`https://documentation.mercanet.bnpparibas.net/index.php/URL`.

#### Exemple fonctionnel sur l'API de test de Sogenactif

Cette exemple permet de valider notre encodage de SEAL et le fait que l'on communique bien avec l'API: 

1. Initialiser le paiement = initialiser une transaction 

URL pour initialiser la transaction via le script distant (appel la page distante)
, on ne saisie pas la carte c'est juste pour valider la bonne communication :

* Verbe: `POST`
* URL: `https://payment-webinit.simu.sogenactif.com/rs-services/v2/paymentInit` 
Body en JSON (car on utilise l'API json, possible en formulaire mais le format n'a plus rien à voir)
```
{ "amount": "1000",
    "automaticResponseUrl" : "https://responseurl.com",
    "currencyCode":"978",
    "interfaceVersion" : "IR_WS_2.3",
    "merchantId": "002010000000002",
    "normalReturnUrl" : "https://responseurl2.com",
    "orderChannel" : "INTERNET",
    "transactionReference" : "1232015021717313",
    "keyVersion" : "1", 
    "seal" : "704db806122ac210e48f22504814fdda85bb1254d56c6f4c33a312846320291c"
}
```

Les informations retournées vont permettre ensuite de pouvoir rediriger l'utilisateur vers la page avec tous ce 
qui va bien et on pourra alors ouvrir une page en transmettant toutes ces données afin de tester l'API:

```
{
    "redirectionData": "FTEx33MrE9Nc0gvtIS0aydJngXH8uuirg3ZpFD_KRM22C9e3IFDdBdSZB3kdQwcyIjWhKpM9mHYTCaCCy7Vm0YWrLscP-TJ895c2GXsTKlyRgzcA6pUALornvWweUQLW-oDhqMKw3Wo8q8SHHqY_nuatEbc84BI21iAW5r7k26LiISDWdyidTmwWSfpta8V_NTqo-A07qPd9-5zRKCr2F91Z8R4HogmLYdx_xh6BOyWg_vXDbDYqSo0BZBq08B24QB9jFRlqPrbbDWOyFKI9bDRzt6GOJUZB0vurhPA_O780oLTt9hJZn0VAJ4S_eXiviZhYBF3QG3I9i5uIPxux5WYOxLaDEvcs00JHSPx5m9Z5R3Q_fSxQ_38CLGbYh9QdVuMu6EsyStzHIol2BOZzn9w0gWKqNIz-Uirn1yAiZ-5MwvB9BkJeCc37KeY0b8ULoIF0xmV5T8tq_w0oBvEW0Fv-k9aTC79TWG5V06s_Jf7ARY6767fWEQXC6DVK94riEmOEinHv1vQSC0AfkFTfMIUe9lnRQ0M9oYIwVVualOaTnljta7UhL0ao1yI6vfl3hHRcBamZvGZg5WtST6YJwZkHsXqdHGg2MT4kF0D1rukvATQEQcowtJconT70vHBwnRlAmM7tPQ8CXfS5K-dw22nYrzSo0iRtm-_Kcv--ZB7W_HtM-NYfr9mW29jp_nyFcv0eCuA8HQIT9uOnKK4W4Ji7U-M9G8I_NsR3IGHNO27VhhlrPTxCGhKMcBaESMVpU1zO701tTz1BwT6_rELHH5zHHu4px6SoK1CsGmCpJv1K_Y2iWU56iwUq7gkpA9_c3rWaLFxMKaMbCVwzbyuJ_5jsl6h8uBz_73vMu1ydzWuCOE_GDeoy5gGA9PoAqm-P-My5ZbSzNa2Sw0UBNzoOiEHFE8djq8qGan3Kiqep-XMQR-YXitpoLP1CZUDkhZRULFW5XYK0_3sH8IYuGEbqxhUlJhX6tASFmsyvKLAOW3FUaDevw3SfbsKgRFDnvH57IXs9as8ynSA--0Vn1jK5k6LrOYLusAv83O6GYulb1GVwHjt73np_2v-W-GNW8ORMenEwZb2UqFYZ-XEOFQcUQDE3UMGVKwszuwWQ9STCw6Ay4mPUXziyNdwwzb2rGHkq84BoKV78Qrv9IJqY9jpLOfOq-C2C7_8rnIfxjpBw5f_XElIfiO2WMt9YIzPDX7zNjRG1n9vBjjzffvsWOQHlG3a5grQKj_5gMR-yQB9CvOBixtYtI9snV5RlNAVXHe5pjRG1n9vBjjzffvsWOQHlG8cYmwOV6PYK29vld6TkM5NxghgbbpvWv-mG8-Gyemh41ZAeJltvTd63AUIFS7eYXH6hjphassHnAfrKXtBpEZLoFsePkAr6YFZLxR4ern4KXtx8jj4HJHklSDAV6fKGopvu0Wtzjy-pWVhmihAq2Rzn5Y-Q9fQtbX2K7jKlrMWxXAfDWxOKku9eyW76mJIu0NpCLcxnG6M8TCYtEuniZznVuQ_a-vNYyoefdSpA-_04hqMa92DPoA85VZbH5KBUuuflj5D19C1tfYruMqWsxbE6rqB975XxhXNG-YXejyGcMFy_nJlidq0KDgRJ1e_q940RtZ_bwY483377FjkB5Ru418CCZ7D3D6SQYP224UkaC8tG_OIkEW3R6N5NMAZhgdK3sqPZPiYGDU7q6T76kxla1JZwz-5wSgABK-wV16UlA1v3M1KtQHKwOVIZVy3VSwephA7nr_67IDBnuW_bdYjqqqfJtu70VoEtZOvxckajzNnF8EvD50cvMbo4Z3CtTc1VL0LFrJXKZwl2Y8S1PrPRq7IeOkFqXiHI8PD0BIxzyQhq2RcxmVHzUkfcJ7xcpVkBH862MhpYtsM1zZgc2-zzgGgpXvxCu_0gmpj2Oks5ero3mCIdLNo46AFgJMsQmDqjl394DwPXwm18x105M32NEbWf28GOPN9--xY5AeUb2OR6T2g6Fw5zlnzE2jMvPHE90JZlyE4gNnAl4X4lJocr45wUqRmBRPPKVGrNUFRD2HVkwemRq94mX-_v6sLWsYq0byaUSSqs2DJdGIX3d_4zUIx4ZTlN0s0GVurntzv42jdaAwJog35e_uRPCFfImi6xoXO8io2_6f5-cxMJ80jmWK8hRQZNA6IW3glC_-0neCXfZZY3l4ADGss34oO-_6jYnxjvQjI5VXG4D0h23qHis39doshq_SiurwTgjBTvjRG1n9vBjjzffvsWOQHlGwoo9iPO-H9GUAQ4fu-jQAh_t4adgcRxCTi-62OulmFwjRG1n9vBjjzffvsWOQHlG_Tv5v4WHGEWSspBw7QnQshoqffe7genzw9g0dfjSwjI0reyo9k-JgYNTurpPvqTGVrUlnDP7nBKAAEr7BXXpSUDW_czUq1AcrA5UhlXLdVLB6mEDuev_rsgMGe5b9t1iOqqp8m27vRWgS1k6_FyRqPM2cXwS8PnRy8xujhncK1NzVUvQsWslcpnCXZjxLU-s9Grsh46QWpeIcjw8PQEjHP-uveuxyhMFwg4KItW5eGV7vFuc-P1BaniiRBCdxMS6FMo8DkSgv9Es0YeCTUvspzoFsePkAr6YFZLxR4ern4KXtx8jj4HJHklSDAV6fKGouflj5D19C1tfYruMqWsxbHKFklVh84iSOSb3vbaUqJuW0ha87kDAgejGCgf0HdOEyW-eEEdKmpp4D6kzakUMTWPEHIHyIwrAkMeHupJI8WQ8_-vYfhUH75tAwoRSp-YfSW-eEEdKmpp4D6kzakUMTUgB4aWxvpT_abjYqoVTFqqJShankIGLiZkvYP_T8BMqY0RtZ_bwY483377FjkB5Rt6cTBlvZSoVhn5cQ4VBxRAH7N3DKaOsuBa9v7wQ6RNv-ZYryFFBk0DohbeCUL_7Sd4Jd9lljeXgAMayzfig77_8_-vYfhUH75tAwoRSp-YfSW-eEEdKmpp4D6kzakUMTXJit6Jx8ZhuyCEvRrJbX4nu7HOC7faf4aiwAtvAw3nx9N8kNJdeUEkEgO7fMd67Rrn5Y-Q9fQtbX2K7jKlrMWxfzrmrDb6KkpyXByPx8jDJ3-3hp2BxHEJOL7rY66WYXB9U0Wd50GK68cyHddLmHhna-OJRMqYFxksSE51DvcPJwLtniDE-w48Z4JIL4lghVTt8hmyoTijpzHYJpCLdc06fJ0Hlh9BrVRNc9FgerYvVRliJmZiexqWhOxp-wled3ZqnmpYgcraC0LD75aygCN5MOGkNX2YFW1v5Sn_7NccECdG2YMi52INNEPD0ItHibgt_kTGMKZSXbjA9IqNggTjkzBo4Y-0XoDRGjP1bx6jisPgMnesSc2leNvtxFqYl_Qtz6OFIpcjmvFWC0UMQdSi07TY5OOYh_DrbWpnwpvJmjdk20M2eNNOFyOSb6MtzkARv6WUaPaCucpfrRbYVipfBpsaBrwhULEZ4oeHa86CrT0SAf6EpWfb_5fPsFn7gr0NQjAx1a9c6ELM2sxIaViZ67qo456dqIh_YkDQ_TYOHRQNoaEXJkyyHs0uySCFW9kKAVpr7DyQ9F6G5ygv3eVLIcLU1rJzFVpaqZU_25anVQ",
    "redirectionStatusCode": "00",
    "redirectionStatusMessage": "INITIALISATION REQUEST ACCEPTED",
    "redirectionUrl": "https://payment-web.simu.sogenactif.com/payment",
    "redirectionVersion": "IR_WS_2.0",
    "seal": "146f3c34dda9940a518d6bb6948c1b1056d269a63ea8370929dacbb4fa3c21c1"
}
```

2. Résoudre cette transaction

Si l’initialisation du paiement s’est correctement déroulée, le champ `redirectionStatusCode` doit être valorisé à « 00 ».
Les champs `redirectionData`, `redirectionVersion` et `redirectionUrl` seront également valorisés pour permettre la redirection 
vers les pages de paiement Sogenactif .

Pour rediriger le client vers les pages de paiement, vous devez implémenter un formulaire de type POST envoyant les deux champs suivants : 
`redirectionData` et `redirectionVersion`. Le formulaire `POST` devra rediriger le client vers l’URL fournie dans le champ redirectionUrl .

Il est nécessaire de faire en sorte d'avoir une nouvelles transaction et de créé un nouveau seal. Autrement dit :

1. changer le numéro de transaction
2. encoder un nouveau seal
3. renvoyer une requête avec le "seal" généré via les tests

Ci-dessous un exemple de formulaire à soumettre de façon automatique en utilisant les infos :

```html
<!DOCTYPE html>
<html>
<head>
    <title>Paiement</title>
    <meta charset="utf-8">
</head>
<body>
    Vous allez être redirigé vers la page de paiement...

    <form name="auto_submit_form" method="post">
        <input type="hidden" name="redirectionVersion">
        <input type="hidden" name="redirectionData">
    </form>

    <script type="text/javascript">
        document.addEventListener("DOMContentLoaded", function(event) {

       var data = {
            "redirectionData": "FTEx33MrE9Nc0gvtIS0aydJngXH8uuirg3ZpFD_KRM22C9e3IFDdBdSZB3kdQwcyIjWhKpM9mHYTCaCCy7Vm0YWrLscP-TJ895c2GXsTKlyRgzcA6pUALornvWweUQLW-oDhqMKw3Wo8q8SHHqY_nuatEbc84BI21iAW5r7k26LiISDWdyidTmwWSfpta8V_NTqo-A07qPd9-5zRKCr2F91Z8R4HogmLYdx_xh6BOyWg_vXDbDYqSo0BZBq08B24QB9jFRlqPrbbDWOyFKI9bDRzt6GOJUZB0vurhPA_O780oLTt9hJZn0VAJ4S_eXiviZhYBF3QG3I9i5uIPxux5WYOxLaDEvcs00JHSPx5m9Z5R3Q_fSxQ_38CLGbYh9QdVuMu6EsyStzHIol2BOZzn9w0gWKqNIz-Uirn1yAiZ-5MwvB9BkJeCc37KeY0b8ULoIF0xmV5T8tq_w0oBvEW0Fv-k9aTC79TWG5V06s_Jf7ARY6767fWEQXC6DVK94riEmOEinHv1vQSC0AfkFTfMIUe9lnRQ0M9oYIwVVualOaTnljta7UhL0ao1yI6vfl3hHRcBamZvGZg5WtST6YJwZkHsXqdHGg2MT4kF0D1rukvATQEQcowtJconT70vHBwnRlAmM7tPQ8CXfS5K-dw22nYrzSo0iRtm-_Kcv--ZB7W_HtM-NYfr9mW29jp_nyFcv0eCuA8HQIT9uOnKK4W4Ji7U-M9G8I_NsR3IGHNO27VhhlrPTxCGhKMcBaESMVpU1zO701tTz1BwT6_rELHH5zHHu4px6SoK1CsGmCpJv1K_Y2iWU56iwUq7gkpA9_c3rWaLFxMKaMbCVwzbyuJ_5jsl6h8uBz_73vMu1ydzWuCOE_GDeoy5gGA9PoAqm-P-My5ZbSzNa2Sw0UBNzoOiEHFE8djq8qGan3Kiqep-XMQR-YXitpoLP1CZUDkhZRULFW5XYK0_3sH8IYuGEbqxhUlJhX6tASFmsyvKLAOW3FUaDevw3SfbsKgRFDnvH57IXs9as8ynSA--0Vn1jK5k6LrOYLusAv83O6GYulb1GVwHjt73np_2v-W-GNW8ORMenEwZb2UqFYZ-XEOFQcUQDE3UMGVKwszuwWQ9STCw6Ay4mPUXziyNdwwzb2rGHkq84BoKV78Qrv9IJqY9jpLOfOq-C2C7_8rnIfxjpBw5f_XElIfiO2WMt9YIzPDX7zNjRG1n9vBjjzffvsWOQHlG3a5grQKj_5gMR-yQB9CvOBixtYtI9snV5RlNAVXHe5pjRG1n9vBjjzffvsWOQHlG8cYmwOV6PYK29vld6TkM5NxghgbbpvWv-mG8-Gyemh41ZAeJltvTd63AUIFS7eYXH6hjphassHnAfrKXtBpEZLoFsePkAr6YFZLxR4ern4KXtx8jj4HJHklSDAV6fKGopvu0Wtzjy-pWVhmihAq2Rzn5Y-Q9fQtbX2K7jKlrMWxXAfDWxOKku9eyW76mJIu0NpCLcxnG6M8TCYtEuniZznVuQ_a-vNYyoefdSpA-_04hqMa92DPoA85VZbH5KBUuuflj5D19C1tfYruMqWsxbE6rqB975XxhXNG-YXejyGcMFy_nJlidq0KDgRJ1e_q940RtZ_bwY483377FjkB5Ru418CCZ7D3D6SQYP224UkaC8tG_OIkEW3R6N5NMAZhgdK3sqPZPiYGDU7q6T76kxla1JZwz-5wSgABK-wV16UlA1v3M1KtQHKwOVIZVy3VSwephA7nr_67IDBnuW_bdYjqqqfJtu70VoEtZOvxckajzNnF8EvD50cvMbo4Z3CtTc1VL0LFrJXKZwl2Y8S1PrPRq7IeOkFqXiHI8PD0BIxzyQhq2RcxmVHzUkfcJ7xcpVkBH862MhpYtsM1zZgc2-zzgGgpXvxCu_0gmpj2Oks5ero3mCIdLNo46AFgJMsQmDqjl394DwPXwm18x105M32NEbWf28GOPN9--xY5AeUb2OR6T2g6Fw5zlnzE2jMvPHE90JZlyE4gNnAl4X4lJocr45wUqRmBRPPKVGrNUFRD2HVkwemRq94mX-_v6sLWsYq0byaUSSqs2DJdGIX3d_4zUIx4ZTlN0s0GVurntzv42jdaAwJog35e_uRPCFfImi6xoXO8io2_6f5-cxMJ80jmWK8hRQZNA6IW3glC_-0neCXfZZY3l4ADGss34oO-_6jYnxjvQjI5VXG4D0h23qHis39doshq_SiurwTgjBTvjRG1n9vBjjzffvsWOQHlGwoo9iPO-H9GUAQ4fu-jQAh_t4adgcRxCTi-62OulmFwjRG1n9vBjjzffvsWOQHlG_Tv5v4WHGEWSspBw7QnQshoqffe7genzw9g0dfjSwjI0reyo9k-JgYNTurpPvqTGVrUlnDP7nBKAAEr7BXXpSUDW_czUq1AcrA5UhlXLdVLB6mEDuev_rsgMGe5b9t1iOqqp8m27vRWgS1k6_FyRqPM2cXwS8PnRy8xujhncK1NzVUvQsWslcpnCXZjxLU-s9Grsh46QWpeIcjw8PQEjHP-uveuxyhMFwg4KItW5eGV7vFuc-P1BaniiRBCdxMS6FMo8DkSgv9Es0YeCTUvspzoFsePkAr6YFZLxR4ern4KXtx8jj4HJHklSDAV6fKGouflj5D19C1tfYruMqWsxbHKFklVh84iSOSb3vbaUqJuW0ha87kDAgejGCgf0HdOEyW-eEEdKmpp4D6kzakUMTWPEHIHyIwrAkMeHupJI8WQ8_-vYfhUH75tAwoRSp-YfSW-eEEdKmpp4D6kzakUMTUgB4aWxvpT_abjYqoVTFqqJShankIGLiZkvYP_T8BMqY0RtZ_bwY483377FjkB5Rt6cTBlvZSoVhn5cQ4VBxRAH7N3DKaOsuBa9v7wQ6RNv-ZYryFFBk0DohbeCUL_7Sd4Jd9lljeXgAMayzfig77_8_-vYfhUH75tAwoRSp-YfSW-eEEdKmpp4D6kzakUMTXJit6Jx8ZhuyCEvRrJbX4nu7HOC7faf4aiwAtvAw3nx9N8kNJdeUEkEgO7fMd67Rrn5Y-Q9fQtbX2K7jKlrMWxfzrmrDb6KkpyXByPx8jDJ3-3hp2BxHEJOL7rY66WYXB9U0Wd50GK68cyHddLmHhna-OJRMqYFxksSE51DvcPJwLtniDE-w48Z4JIL4lghVTt8hmyoTijpzHYJpCLdc06fJ0Hlh9BrVRNc9FgerYvVRliJmZiexqWhOxp-wled3ZqnmpYgcraC0LD75aygCN5MOGkNX2YFW1v5Sn_7NccECdG2YMi52INNEPD0ItHibgt_kTGMKZSXbjA9IqNggTjkzBo4Y-0XoDRGjP1bx6jisPgMnesSc2leNvtxFqYl_Qtz6OFIpcjmvFWC0UMQdSi07TY5OOYh_DrbWpnwpvJmjdk20M2eNNOFyOSb6MtzkARv6WUaPaCucpfrRbYVipfBpsaBrwhULEZ4oeHa86CrT0SAf6EpWfb_5fPsFn7gr0NQjAx1a9c6ELM2sxIaViZ67qo456dqIh_YkDQ_TYOHRQNoaEXJkyyHs0uySCFW9kKAVpr7DyQ9F6G5ygv3eVLIcLU1rJzFVpaqZU_25anVQ",
            "redirectionStatusCode": "00",
            "redirectionStatusMessage": "INITIALISATION REQUEST ACCEPTED",
            "redirectionUrl": "https://payment-web.simu.sogenactif.com/payment",
            "redirectionVersion": "IR_WS_2.0",
            "seal": "146f3c34dda9940a518d6bb6948c1b1056d269a63ea8370929dacbb4fa3c21c1"
        };

            var form = document.forms["auto_submit_form"];

            form.action = data.redirectionUrl;
            form.elements.redirectionVersion.value = data.redirectionVersion;
            form.elements.redirectionData.value = data.redirectionData;

            // console.log(form);
            form.submit();

        });
    </script>
</body>
</html>
```

3. Valider un paiement avec les cartes de test et faire ceci afin de validé l'étape suivante : le traitement des retours
 de l'utilisation sur l'application

4. Si on annule ou si on réussi (avec 3-D secure) le retour se fera sur le paramêtre `normalReturnUrl`.

Ce sera l'url de l'action Status du moyen de paiement qui va traiter le retour et faire avancer ou non le paiement.

#### Gestion du status via le workflow Payum dans Sylius

1. Lorsque l'on met en place Payum il est nécessaire de mettre en place les Actions:

* `Capture` : mâche la requête et recupère les infos, **CHAQUE REQUÊTE PASSENT D'ABORD DANS LE CAPTURE**
* `Status`: gère le status en ayant les infos maché par le `Capture`. La stack Symfony et la request ne sont plus accessible.

2. Le flux de gestion de la requête est le suivant:

    1. Je choisi mon mode de paiement
    2. Passage dans le `Capture` pour initialiser le paiement
    3. Redirection depuis le capture
    4. Validation du paiement par le client (redirection grâce à la classe payum qui créé le formulaire de redirection à la volée)
    5. Passage dans le `Capture` pour le retour de la validation (stockage de l'ensemble des infos)
    6. Pas de redirection car on a des `Data`
    7. Passage dans le `Status` pour vérifier les `Data` fournis par le capture.

#### Soit 00 soit rien

Le code de reponse `responseCode` doit être à `00` sinon c'est `05` ou whatever. On stock alors tout le retour dans les 
deux cas.
